@@ -24,7 +24,7 @@ from slither.utils.tests_pattern import is_test_contract
 
 # pylint: disable=too-many-lines,too-many-instance-attributes,import-outside-toplevel,too-many-nested-blocks
 if TYPE_CHECKING:
-    from slither.utils.type_helpers import LibraryCallType, HighLevelCallType
+    from slither.utils.type_helpers import LibraryCallType, HighLevelCallType, InternalCallType
     from slither.core.declarations import Enum, Event, Modifier
     from slither.core.declarations import Structure
     from slither.slithir.variables.variable import SlithIRVariable
@@ -71,12 +71,15 @@ class Contract(ChildSlither, SourceMapping):  # pylint: disable=too-many-public-
         self._is_upgradeable: Optional[bool] = None
         self._is_upgradeable_proxy: Optional[bool] = None
 
-        self._is_top_level = False
+        self.is_top_level = False  # heavily used, so no @property
 
         self._initial_state_variables: List["StateVariable"] = []  # ssa
 
         self._is_incorrectly_parsed: bool = False
 
+        self._available_functions_as_dict: Optional[Dict[str, "Function"]] = None
+        self._all_functions_called: Optional[List["InternalCallType"]] = None
+
     ###################################################################################
     ###################################################################################
     # region General's properties
@@ -282,8 +285,8 @@ class Contract(ChildSlither, SourceMapping):  # pylint: disable=too-many-public-
         """
         List all of the slithir variables (non SSA)
         """
-        slithir_variables = [f.slithir_variables for f in self.functions + self.modifiers]  # type: ignore
-        slithir_variables = [item for sublist in slithir_variables for item in sublist]
+        slithir_variabless = [f.slithir_variables for f in self.functions + self.modifiers]  # type: ignore
+        slithir_variables = [item for sublist in slithir_variabless for item in sublist]
         return list(set(slithir_variables))
 
     # endregion
@@ -392,7 +395,11 @@ class Contract(ChildSlither, SourceMapping):  # pylint: disable=too-many-public-
         return list(self._functions.values())
 
     def available_functions_as_dict(self) -> Dict[str, "Function"]:
-        return {f.full_name: f for f in self._functions.values() if not f.is_shadowed}
+        if self._available_functions_as_dict is None:
+            self._available_functions_as_dict = {
+                f.full_name: f for f in self._functions.values() if not f.is_shadowed
+            }
+        return self._available_functions_as_dict
 
     def add_function(self, func: "Function"):
         self._functions[func.canonical_name] = func
@@ -726,33 +733,35 @@ class Contract(ChildSlither, SourceMapping):  # pylint: disable=too-many-public-
     ###################################################################################
 
     @property
-    def all_functions_called(self) -> List["Function"]:
+    def all_functions_called(self) -> List["InternalCallType"]:
         """
         list(Function): List of functions reachable from the contract
         Includes super, and private/internal functions not shadowed
         """
-        all_calls = [f for f in self.functions + self.modifiers if not f.is_shadowed]  # type: ignore
-        all_callss = [f.all_internal_calls() for f in all_calls] + [all_calls]
-        all_calls = [item for sublist in all_callss for item in sublist]
-        all_calls = list(set(all_calls))
+        if self._all_functions_called is None:
+            all_functions = [f for f in self.functions + self.modifiers if not f.is_shadowed]  # type: ignore
+            all_callss = [f.all_internal_calls() for f in all_functions] + [list(all_functions)]
+            all_calls = [item for sublist in all_callss for item in sublist]
+            all_calls = list(set(all_calls))
 
-        all_constructors = [c.constructor for c in self.inheritance if c.constructor]
-        all_constructors = list(set(all_constructors))
+            all_constructors = [c.constructor for c in self.inheritance if c.constructor]
+            all_constructors = list(set(all_constructors))
 
-        set_all_calls = set(all_calls + all_constructors)
+            set_all_calls = set(all_calls + list(all_constructors))
 
-        return [c for c in set_all_calls if isinstance(c, Function)]
+            self._all_functions_called = [c for c in set_all_calls if isinstance(c, Function)]
+        return self._all_functions_called
 
     @property
     def all_state_variables_written(self) -> List["StateVariable"]:
         """
         list(StateVariable): List all of the state variables written
         """
-        all_state_variables_written = [
+        all_state_variables_writtens = [
             f.all_state_variables_written() for f in self.functions + self.modifiers  # type: ignore
         ]
         all_state_variables_written = [
-            item for sublist in all_state_variables_written for item in sublist
+            item for sublist in all_state_variables_writtens for item in sublist
         ]
         return list(set(all_state_variables_written))
 
@@ -761,11 +770,11 @@ class Contract(ChildSlither, SourceMapping):  # pylint: disable=too-many-public-
         """
         list(StateVariable): List all of the state variables read
         """
-        all_state_variables_read = [
+        all_state_variables_reads = [
             f.all_state_variables_read() for f in self.functions + self.modifiers  # type: ignore
         ]
         all_state_variables_read = [
-            item for sublist in all_state_variables_read for item in sublist
+            item for sublist in all_state_variables_reads for item in sublist
         ]
         return list(set(all_state_variables_read))
 
@@ -774,8 +783,8 @@ class Contract(ChildSlither, SourceMapping):  # pylint: disable=too-many-public-
         """
         list((Contract, Function): List all of the libraries func called
         """
-        all_high_level_calls = [f.all_library_calls() for f in self.functions + self.modifiers]  # type: ignore
-        all_high_level_calls = [item for sublist in all_high_level_calls for item in sublist]
+        all_high_level_callss = [f.all_library_calls() for f in self.functions + self.modifiers]  # type: ignore
+        all_high_level_calls = [item for sublist in all_high_level_callss for item in sublist]
         return list(set(all_high_level_calls))
 
     @property
@@ -783,8 +792,8 @@ class Contract(ChildSlither, SourceMapping):  # pylint: disable=too-many-public-
         """
         list((Contract, Function|Variable)): List all of the external high level calls
         """
-        all_high_level_calls = [f.all_high_level_calls() for f in self.functions + self.modifiers]  # type: ignore
-        all_high_level_calls = [item for sublist in all_high_level_calls for item in sublist]
+        all_high_level_callss = [f.all_high_level_calls() for f in self.functions + self.modifiers]  # type: ignore
+        all_high_level_calls = [item for sublist in all_high_level_callss for item in sublist]
         return list(set(all_high_level_calls))
 
     # endregion
@@ -794,9 +803,7 @@ class Contract(ChildSlither, SourceMapping):  # pylint: disable=too-many-public-
     ###################################################################################
     ###################################################################################
 
-    def get_summary(
-        self, include_shadowed=True
-    ) -> Tuple[str, List[str], List[str], List[str], List[str]]:
+    def get_summary(self, include_shadowed=True) -> Tuple[str, List[str], List[str], List, List]:
         """Return the function summary
 
         :param include_shadowed: boolean to indicate if shadowed functions should be included (default True)
@@ -838,15 +845,15 @@ class Contract(ChildSlither, SourceMapping):  # pylint: disable=too-many-public-
         :return: list of string
         """
         all_erc = [
-            ("ERC20", lambda x: x.is_erc20()),
-            ("ERC165", lambda x: x.is_erc165()),
-            ("ERC1820", lambda x: x.is_erc1820()),
-            ("ERC223", lambda x: x.is_erc223()),
-            ("ERC721", lambda x: x.is_erc721()),
-            ("ERC777", lambda x: x.is_erc777()),
+            ("ERC20", self.is_erc20),
+            ("ERC165", self.is_erc165),
+            ("ERC1820", self.is_erc1820),
+            ("ERC223", self.is_erc223),
+            ("ERC721", self.is_erc721),
+            ("ERC777", self.is_erc777),
         ]
 
-        return [erc[0] for erc in all_erc if erc[1](self)]
+        return [erc for erc, is_erc in all_erc if is_erc()]
 
     def is_erc20(self) -> bool:
         """
@@ -856,7 +863,7 @@ class Contract(ChildSlither, SourceMapping):  # pylint: disable=too-many-public-
         :return: Returns a true if the contract is an erc20
         """
         full_names = self.functions_signatures
-        return all((s in full_names for s in ERC20_signatures))
+        return all(s in full_names for s in ERC20_signatures)
 
     def is_erc165(self) -> bool:
         """
@@ -866,7 +873,7 @@ class Contract(ChildSlither, SourceMapping):  # pylint: disable=too-many-public-
         :return: Returns a true if the contract is an erc165
         """
         full_names = self.functions_signatures
-        return all((s in full_names for s in ERC165_signatures))
+        return all(s in full_names for s in ERC165_signatures)
 
     def is_erc1820(self) -> bool:
         """
@@ -876,7 +883,7 @@ class Contract(ChildSlither, SourceMapping):  # pylint: disable=too-many-public-
         :return: Returns a true if the contract is an erc165
         """
         full_names = self.functions_signatures
-        return all((s in full_names for s in ERC1820_signatures))
+        return all(s in full_names for s in ERC1820_signatures)
 
     def is_erc223(self) -> bool:
         """
@@ -886,7 +893,7 @@ class Contract(ChildSlither, SourceMapping):  # pylint: disable=too-many-public-
         :return: Returns a true if the contract is an erc223
         """
         full_names = self.functions_signatures
-        return all((s in full_names for s in ERC223_signatures))
+        return all(s in full_names for s in ERC223_signatures)
 
     def is_erc721(self) -> bool:
         """
@@ -896,7 +903,7 @@ class Contract(ChildSlither, SourceMapping):  # pylint: disable=too-many-public-
         :return: Returns a true if the contract is an erc721
         """
         full_names = self.functions_signatures
-        return all((s in full_names for s in ERC721_signatures))
+        return all(s in full_names for s in ERC721_signatures)
 
     def is_erc777(self) -> bool:
         """
@@ -906,7 +913,7 @@ class Contract(ChildSlither, SourceMapping):  # pylint: disable=too-many-public-
         :return: Returns a true if the contract is an erc165
         """
         full_names = self.functions_signatures
-        return all((s in full_names for s in ERC777_signatures))
+        return all(s in full_names for s in ERC777_signatures)
 
     @property
     def is_token(self) -> bool:
@@ -1097,6 +1104,7 @@ class Contract(ChildSlither, SourceMapping):  # pylint: disable=too-many-public-
                             v.node_initialization = next_node
                             prev_node.add_son(next_node)
                             next_node.add_father(prev_node)
+                            prev_node = next_node
                             counter += 1
                     break
 
@@ -1124,6 +1132,7 @@ class Contract(ChildSlither, SourceMapping):  # pylint: disable=too-many-public-
                             v.node_initialization = next_node
                             prev_node.add_son(next_node)
                             next_node.add_father(prev_node)
+                            prev_node = next_node
                             counter += 1
 
                     break
@@ -1141,6 +1150,7 @@ class Contract(ChildSlither, SourceMapping):  # pylint: disable=too-many-public-
         node.set_offset(variable.source_mapping, self.slither)
         node.set_function(func)
         func.add_node(node)
+        assert variable.expression
         expression = AssignmentOperation(
             Identifier(variable),
             variable.expression,
@@ -1199,19 +1209,6 @@ class Contract(ChildSlither, SourceMapping):  # pylint: disable=too-many-public-
         for func in self.functions + self.modifiers:
             func.fix_phi(last_state_variables_instances, initial_state_variables_instances)
 
-    @property
-    def is_top_level(self) -> bool:
-        """
-        The "TopLevel" contract is used to hold structures and enums defined at the top level
-        ie. structures and enums that are represented outside of any contract
-        :return:
-        """
-        return self._is_top_level
-
-    @is_top_level.setter
-    def is_top_level(self, t: bool):
-        self._is_top_level = t
-
     # endregion
     ###################################################################################
     ###################################################################################
