@@ -53,10 +53,7 @@ ReacheableNode = namedtuple("ReacheableNode", ["node", "ir"])
 
 class ModifierStatements:
     def __init__(
-        self,
-        modifier: Union["Contract", "Function"],
-        entry_point: "Node",
-        nodes: List["Node"],
+        self, modifier: Union["Contract", "Function"], entry_point: "Node", nodes: List["Node"],
     ):
         self._modifier = modifier
         self._entry_point = entry_point
@@ -200,6 +197,15 @@ class Function(
 
         self._counter_nodes = 0
 
+        # Memoize parameters:
+        # TODO: identify all the memoize parameters and add a way to undo the memoization
+        self._full_name: Optional[str] = None
+        self._signature: Optional[Tuple[str, List[str], List[str]]] = None
+        self._solidity_signature: Optional[str] = None
+        self._signature_str: Optional[str] = None
+        self._canonical_name: Optional[str] = None
+        self._is_protected: Optional[bool] = None
+
     ###################################################################################
     ###################################################################################
     # region General properties
@@ -247,8 +253,11 @@ class Function(
         str: func_name(type1,type2)
         Return the function signature without the return values
         """
-        name, parameters, _ = self.signature
-        return ".".join(self._scope + [name]) + "(" + ",".join(parameters) + ")"
+        if self._full_name is None:
+            name, parameters, _ = self.signature
+            full_name = ".".join(self._scope + [name]) + "(" + ",".join(parameters) + ")"
+            self._full_name = full_name
+        return self._full_name
 
     @property
     def canonical_name(self) -> str:
@@ -256,13 +265,15 @@ class Function(
         str: contract.func_name(type1,type2)
         Return the function signature without the return values
         """
-        name, parameters, _ = self.signature
-        return (
-            ".".join([self.contract_declarer.name] + self._scope + [name])
-            + "("
-            + ",".join(parameters)
-            + ")"
-        )
+        if self._canonical_name is None:
+            name, parameters, _ = self.signature
+            self._canonical_name = (
+                ".".join([self.contract_declarer.name] + self._scope + [name])
+                + "("
+                + ",".join(parameters)
+                + ")"
+            )
+        return self._canonical_name
 
     @property
     def contains_assembly(self) -> bool:
@@ -924,8 +935,12 @@ class Function(
         Contract and converted into address
         :return: the solidity signature
         """
-        parameters = [self._convert_type_for_solidity_signature(x.type) for x in self.parameters]
-        return self.name + "(" + ",".join(parameters) + ")"
+        if self._solidity_signature is None:
+            parameters = [
+                self._convert_type_for_solidity_signature(x.type) for x in self.parameters
+            ]
+            self._solidity_signature = self.name + "(" + ",".join(parameters) + ")"
+        return self._solidity_signature
 
     @property
     def signature(self) -> Tuple[str, List[str], List[str]]:
@@ -933,11 +948,14 @@ class Function(
         (str, list(str), list(str)): Function signature as
         (name, list parameters type, list return values type)
         """
-        return (
-            self.name,
-            [str(x.type) for x in self.parameters],
-            [str(x.type) for x in self.returns],
-        )
+        if self._signature is None:
+            signature = (
+                self.name,
+                [str(x.type) for x in self.parameters],
+                [str(x.type) for x in self.returns],
+            )
+            self._signature = signature
+        return self._signature
 
     @property
     def signature_str(self) -> str:
@@ -945,8 +963,12 @@ class Function(
         str: func_name(type1,type2) returns (type3)
         Return the function signature as a str (contains the return values)
         """
-        name, parameters, returnVars = self.signature
-        return name + "(" + ",".join(parameters) + ") returns(" + ",".join(returnVars) + ")"
+        if self._signature_str is None:
+            name, parameters, returnVars = self.signature
+            self._signature_str = (
+                name + "(" + ",".join(parameters) + ") returns(" + ",".join(returnVars) + ")"
+            )
+        return self._signature_str
 
     # endregion
     ###################################################################################
@@ -1144,9 +1166,7 @@ class Function(
 
     @staticmethod
     def _explore_func_conditional(
-        func: "Function",
-        f: Callable[["Node"], List[SolidityVariable]],
-        include_loop: bool,
+        func: "Function", f: Callable[["Node"], List[SolidityVariable]], include_loop: bool,
     ):
         ret = [f(n) for n in func.nodes if n.is_conditional(include_loop)]
         return [item for sublist in ret for item in sublist]
@@ -1298,7 +1318,7 @@ class Function(
         with open(filename, "w", encoding="utf8") as f:
             f.write(content)
 
-    def slithir_cfg_to_dot_str(self) -> str:
+    def slithir_cfg_to_dot_str(self, skip_expressions=False) -> str:
         """
         Export the CFG to a DOT format. The nodes includes the Solidity expressions and the IRs
         :return: the DOT content
@@ -1310,9 +1330,9 @@ class Function(
         content += "digraph{\n"
         for node in self.nodes:
             label = "Node Type: {} {}\n".format(str(node.type), node.node_id)
-            if node.expression:
+            if node.expression and not skip_expressions:
                 label += "\nEXPRESSION:\n{}\n".format(node.expression)
-            if node.irs:
+            if node.irs and not skip_expressions:
                 label += "\nIRs:\n" + "\n".join([str(ir) for ir in node.irs])
             content += '{}[label="{}"];\n'.format(node.node_id, label)
             if node.type in [NodeType.IF, NodeType.IFLOOP]:
@@ -1412,11 +1432,16 @@ class Function(
             (bool)
         """
 
-        if self.is_constructor:
-            return True
-        conditional_vars = self.all_conditional_solidity_variables_read(include_loop=False)
-        args_vars = self.all_solidity_variables_used_as_args()
-        return SolidityVariableComposed("msg.sender") in conditional_vars + args_vars
+        if self._is_protected is None:
+            if self.is_constructor:
+                self._is_protected = True
+                return True
+            conditional_vars = self.all_conditional_solidity_variables_read(include_loop=False)
+            args_vars = self.all_solidity_variables_used_as_args()
+            self._is_protected = (
+                SolidityVariableComposed("msg.sender") in conditional_vars + args_vars
+            )
+        return self._is_protected
 
     # endregion
     ###################################################################################
@@ -1602,14 +1627,10 @@ class Function(
 
         return ret
 
-    def get_last_ssa_state_variables_instances(
-        self,
-    ) -> Dict[str, Set["SlithIRVariable"]]:
+    def get_last_ssa_state_variables_instances(self,) -> Dict[str, Set["SlithIRVariable"]]:
         return self._get_last_ssa_variable_instances(target_state=True, target_local=False)
 
-    def get_last_ssa_local_variables_instances(
-        self,
-    ) -> Dict[str, Set["SlithIRVariable"]]:
+    def get_last_ssa_local_variables_instances(self,) -> Dict[str, Set["SlithIRVariable"]]:
         return self._get_last_ssa_variable_instances(target_state=False, target_local=True)
 
     @staticmethod
