@@ -76,6 +76,7 @@ class SlitherCore(Context):  # pylint: disable=too-many-instance-attributes,too-
 
         # If set to true, slither will not catch errors during parsing
         self._disallow_partial: bool = False
+        self._skip_assembly: bool = False
 
     ###################################################################################
     ###################################################################################
@@ -273,7 +274,7 @@ class SlitherCore(Context):  # pylint: disable=too-many-instance-attributes,too-
             - The --exclude-dependencies flag is set and results are only related to dependencies
         """
         source_mapping_elements = [
-            elem["source_mapping"]["filename_absolute"]
+            elem["source_mapping"].get("filename_absolute", "unknown")
             for elem in r["elements"]
             if "source_mapping" in elem
         ]
@@ -390,6 +391,10 @@ class SlitherCore(Context):  # pylint: disable=too-many-instance-attributes,too-
         """
         return self._disallow_partial
 
+    @property
+    def skip_assembly(self) -> bool:
+        return self._skip_assembly
+
     # endregion
     ###################################################################################
     ###################################################################################
