@@ -9,23 +9,25 @@ from collections import namedtuple, defaultdict
 from slither.detectors.abstract_detector import DetectorClassification
 from .reentrancy import Reentrancy, to_hashable
 
-FindingKey = namedtuple('FindingKey', ['function', 'calls', 'send_eth'])
-FindingValue = namedtuple('FindingValue', ['variable', 'node', 'nodes'])
+FindingKey = namedtuple("FindingKey", ["function", "calls", "send_eth"])
+FindingValue = namedtuple("FindingValue", ["variable", "node", "nodes"])
 
 
 class ReentrancyEvent(Reentrancy):
-    ARGUMENT = 'reentrancy-events'
-    HELP = 'Reentrancy vulnerabilities leading to out-of-order Events'
+    ARGUMENT = "reentrancy-events"
+    HELP = "Reentrancy vulnerabilities leading to out-of-order Events"
     IMPACT = DetectorClassification.LOW
     CONFIDENCE = DetectorClassification.MEDIUM
 
-    WIKI = 'https://github.com/crytic/slither/wiki/Detector-Documentation#reentrancy-vulnerabilities-3'
+    WIKI = (
+        "https://github.com/crytic/slither/wiki/Detector-Documentation#reentrancy-vulnerabilities-3"
+    )
 
-    WIKI_TITLE = 'Reentrancy vulnerabilities'
-    WIKI_DESCRIPTION = '''
-Detection of the [re-entrancy bug](https://github.com/trailofbits/not-so-smart-contracts/tree/master/reentrancy).
-Only report reentrancies leading to out-of-order Events'''
-    WIKI_EXPLOIT_SCENARIO = '''
+    WIKI_TITLE = "Reentrancy vulnerabilities"
+    WIKI_DESCRIPTION = """
+Detection of the [reentrancy bug](https://github.com/trailofbits/not-so-smart-contracts/tree/master/reentrancy).
+Only report reentrancies leading to out-of-order events."""
+    WIKI_EXPLOIT_SCENARIO = """
 ```solidity
     function bug(Called d){
         counter += 1;
@@ -34,9 +36,9 @@ Only report reentrancies leading to out-of-order Events'''
     }
 ```
 
-If `d.()` reenters, the `Counter` events will be showed in an incorrect order, which might lead to issues for third-parties.'''
+If `d.()` re-enters, the `Counter` events will be shown in an incorrect order, which might lead to issues for third parties."""
 
-    WIKI_RECOMMENDATION = 'Apply the [check-effects-interactions pattern](http://solidity.readthedocs.io/en/v0.4.21/security-considerations.html#re-entrancy).'
+    WIKI_RECOMMENDATION = "Apply the [`check-effects-interactions` pattern](http://solidity.readthedocs.io/en/v0.4.21/security-considerations.html#re-entrancy)."
 
     STANDARD_JSON = False
 
@@ -53,21 +55,21 @@ If `d.()` reenters, the `Counter` events will be showed in an incorrect order, w
                             continue
 
                         # calls are ordered
-                        finding_key = FindingKey(function=node.function,
-                                                 calls=to_hashable(node.context[self.KEY].calls),
-                                                 send_eth=to_hashable(node.context[self.KEY].send_eth))
-                        finding_vars = set([FindingValue(e,
-                                                         e.node,
-                                                         tuple(sorted(nodes, key=lambda x: x.node_id)))
-                                            for (e, nodes)
-                                            in node.context[self.KEY].events.items()])
+                        finding_key = FindingKey(
+                            function=node.function,
+                            calls=to_hashable(node.context[self.KEY].calls),
+                            send_eth=to_hashable(node.context[self.KEY].send_eth),
+                        )
+                        finding_vars = {
+                            FindingValue(e, e.node, tuple(sorted(nodes, key=lambda x: x.node_id)),)
+                            for (e, nodes) in node.context[self.KEY].events.items()
+                        }
                         if finding_vars:
                             result[finding_key] |= finding_vars
         return result
 
-    def _detect(self):
-        """
-        """
+    def _detect(self):  # pylint: disable=too-many-branches
+        """"""
         super()._detect()
 
         reentrancies = self.find_reentrancies()
@@ -78,28 +80,28 @@ If `d.()` reenters, the `Counter` events will be showed in an incorrect order, w
         for (func, calls, send_eth), events in result_sorted:
             calls = sorted(list(set(calls)), key=lambda x: x[0].node_id)
             send_eth = sorted(list(set(send_eth)), key=lambda x: x[0].node_id)
-            events = sorted(events, key=lambda x: (x.variable.name, x.node.node_id))
+            events = sorted(events, key=lambda x: (str(x.variable.name), x.node.node_id))
 
-            info = ['Reentrancy in ', func, ':\n']
-            info += ['\tExternal calls:\n']
+            info = ["Reentrancy in ", func, ":\n"]
+            info += ["\tExternal calls:\n"]
             for (call_info, calls_list) in calls:
-                info += ['\t- ', call_info, '\n']
+                info += ["\t- ", call_info, "\n"]
                 for call_list_info in calls_list:
                     if call_list_info != call_info:
-                        info += ['\t\t- ', call_list_info, '\n']
+                        info += ["\t\t- ", call_list_info, "\n"]
             if calls != send_eth and send_eth:
-                info += ['\tExternal calls sending eth:\n']
+                info += ["\tExternal calls sending eth:\n"]
                 for (call_info, calls_list) in send_eth:
-                    info += ['\t- ', call_info, '\n']
+                    info += ["\t- ", call_info, "\n"]
                     for call_list_info in calls_list:
                         if call_list_info != call_info:
-                            info += ['\t\t- ', call_list_info, '\n']
-            info += ['\tEvent emitted after the call(s):\n']
+                            info += ["\t\t- ", call_list_info, "\n"]
+            info += ["\tEvent emitted after the call(s):\n"]
             for finding_value in events:
-                info += ['\t- ', finding_value.node, '\n']
+                info += ["\t- ", finding_value.node, "\n"]
                 for other_node in finding_value.nodes:
                     if other_node != finding_value.node:
-                        info += ['\t\t- ', other_node, '\n']
+                        info += ["\t\t- ", other_node, "\n"]
 
             # Create our JSON result
             res = self.generate_result(info)
@@ -109,38 +111,30 @@ If `d.()` reenters, the `Counter` events will be showed in an incorrect order, w
 
             # Add all underlying calls in the function which are potentially problematic.
             for (call_info, calls_list) in calls:
-                res.add(call_info, {
-                    "underlying_type": "external_calls"
-                })
+                res.add(call_info, {"underlying_type": "external_calls"})
                 for call_list_info in calls_list:
                     if call_list_info != call_info:
-                        res.add(call_list_info, {
-                            "underlying_type": "external_calls_sending_eth"
-                        })
+                        res.add(
+                            call_list_info, {"underlying_type": "external_calls_sending_eth"},
+                        )
 
             #
 
             # If the calls are not the same ones that send eth, add the eth sending nodes.
             if calls != send_eth:
                 for (call_info, calls_list) in send_eth:
-                    res.add(call_info, {
-                        "underlying_type": "external_calls_sending_eth"
-                    })
+                    res.add(call_info, {"underlying_type": "external_calls_sending_eth"})
                     for call_list_info in calls_list:
                         if call_list_info != call_info:
-                            res.add(call_list_info, {
-                                "underlying_type": "external_calls_sending_eth"
-                            })
+                            res.add(
+                                call_list_info, {"underlying_type": "external_calls_sending_eth"},
+                            )
 
             for finding_value in events:
-                res.add(finding_value.node, {
-                    "underlying_type": "event"
-                })
+                res.add(finding_value.node, {"underlying_type": "event"})
                 for other_node in finding_value.nodes:
                     if other_node != finding_value.node:
-                        res.add(other_node, {
-                            "underlying_type": "event"
-                        })
+                        res.add(other_node, {"underlying_type": "event"})
 
             # Append our result
             results.append(res)
