@@ -59,6 +59,7 @@ class Slither(SlitherCore):  # pylint: disable=too-many-instance-attributes
         self._parser: SlitherSolc  #  This could be another parser, like SlitherVyper, interface needs to be determined
 
         self._disallow_partial: bool = kwargs.get("disallow_partial", False)
+        self._skip_assembly: bool = kwargs.get("skip_assembly", False)
 
         # list of files provided (see --splitted option)
         if isinstance(target, list):
@@ -97,7 +98,11 @@ class Slither(SlitherCore):  # pylint: disable=too-many-instance-attributes
         triage_mode = kwargs.get("triage_mode", False)
         self._triage_mode = triage_mode
 
-        self._parser.analyze_contracts()
+        self._parser.parse_contracts()
+
+        # skip_analyze is only used for testing
+        if not kwargs.get("skip_analyze", False):
+            self._parser.analyze_contracts()
 
     def _init_from_raw_json(self, filename):
         if not os.path.isfile(filename):
