@@ -206,8 +206,7 @@ def convert_arguments(arguments):
 
 def is_temporary(ins):
     return isinstance(
-        ins,
-        (Argument, TmpNewElementaryType, TmpNewContract, TmpNewArray, TmpNewStructure),
+        ins, (Argument, TmpNewElementaryType, TmpNewContract, TmpNewArray, TmpNewStructure),
     )
 
 
@@ -334,11 +333,11 @@ def propagate_type_and_convert_call(result, node):
                 result[idx] = ins
 
         if isinstance(ins, Argument):
+            # In case of dupplicate arguments we overwrite the value
+            # This can happen because of addr.call.value(1).value(2)
             if ins.get_type() in [ArgumentType.GAS]:
-                assert not ins.call_id in calls_gas
                 calls_gas[ins.call_id] = ins.argument
             elif ins.get_type() in [ArgumentType.VALUE]:
-                assert not ins.call_id in calls_value
                 calls_value[ins.call_id] = ins.argument
             else:
                 assert ins.get_type() == ArgumentType.CALL
@@ -364,39 +363,12 @@ def propagate_type_and_convert_call(result, node):
         new_ins = propagate_types(ins, node)
         if new_ins:
             if isinstance(new_ins, (list,)):
-                if len(new_ins) == 2:
-                    new_ins[0].set_node(ins.node)
-                    new_ins[1].set_node(ins.node)
-                    del result[idx]
-                    result.insert(idx, new_ins[0])
-                    result.insert(idx + 1, new_ins[1])
-                    idx = idx + 1
-                elif len(new_ins) == 3:
-                    new_ins[0].set_node(ins.node)
-                    new_ins[1].set_node(ins.node)
-                    new_ins[2].set_node(ins.node)
-                    del result[idx]
-                    result.insert(idx, new_ins[0])
-                    result.insert(idx + 1, new_ins[1])
-                    result.insert(idx + 2, new_ins[2])
-                    idx = idx + 2
-                else:
-                    # Pop conversion
-                    assert len(new_ins) == 6
-                    new_ins[0].set_node(ins.node)
-                    new_ins[1].set_node(ins.node)
-                    new_ins[2].set_node(ins.node)
-                    new_ins[3].set_node(ins.node)
-                    new_ins[4].set_node(ins.node)
-                    new_ins[5].set_node(ins.node)
-                    del result[idx]
-                    result.insert(idx, new_ins[0])
-                    result.insert(idx + 1, new_ins[1])
-                    result.insert(idx + 2, new_ins[2])
-                    result.insert(idx + 3, new_ins[3])
-                    result.insert(idx + 4, new_ins[4])
-                    result.insert(idx + 5, new_ins[5])
-                    idx = idx + 5
+                for new_ins_ in new_ins:
+                    new_ins_.set_node(ins.node)
+                del result[idx]
+                for i, ins in enumerate(new_ins):
+                    result.insert(idx + i, ins)
+                idx = idx + len(new_ins) - 1
             else:
                 new_ins.set_node(ins.node)
                 result[idx] = new_ins
@@ -456,6 +428,9 @@ def _convert_type_contract(ir, slither):
         assignment.lvalue.set_type(ElementaryType("string"))
         return assignment
 
+    if isinstance(contract, ElementaryType):
+        print(contract.type)
+
     raise SlithIRError(f"type({contract.name}).{ir.variable_right} is unknown")
 
 
@@ -516,7 +491,7 @@ def propagate_types(ir, node):  # pylint: disable=too-many-locals
                 if isinstance(t, ArrayType) or (
                     isinstance(t, ElementaryType) and t.type == "bytes"
                 ):
-                    if ir.function_name == "push" and len(ir.arguments) == 1:
+                    if ir.function_name == "push" and len(ir.arguments) <= 1:
                         return convert_to_push(ir, node)
                     if ir.function_name == "pop" and len(ir.arguments) == 0:
                         return convert_to_pop(ir, node)
@@ -646,8 +621,7 @@ def propagate_types(ir, node):  # pylint: disable=too-many-locals
                             # We dont need to check for function collision, as solc prevents the use of selector
                             # if there are multiple functions with the same name
                             f = next(
-                                (f for f in type_t.functions if f.name == ir.variable_right),
-                                None,
+                                (f for f in type_t.functions if f.name == ir.variable_right), None,
                             )
                             if f:
                                 ir.lvalue.set_type(f)
@@ -854,10 +828,7 @@ def extract_tmp_call(ins, contract):  # pylint: disable=too-many-locals
             ins.called = SolidityFunction("blockhash(uint256)")
         elif str(ins.called) == "this.balance":
             s = SolidityCall(
-                SolidityFunction("this.balance()"),
-                ins.nbr_arguments,
-                ins.lvalue,
-                ins.type_call,
+                SolidityFunction("this.balance()"), ins.nbr_arguments, ins.lvalue, ins.type_call,
             )
             s.set_expression(ins.expression)
             return s
@@ -1026,67 +997,94 @@ def convert_to_solidity_func(ir):
     return new_ir
 
 
+def convert_to_push_expand_arr(ir, node, ret):
+    arr = ir.destination
+
+    length = ReferenceVariable(node)
+    length.set_type(ElementaryType("uint256"))
+
+    ir_length = Length(arr, length)
+    ir_length.set_expression(ir.expression)
+    ir_length.set_node(ir.node)
+    ir_length.lvalue.points_to = arr
+    ret.append(ir_length)
+
+    length_val = TemporaryVariable(node)
+    length_val.set_type(ElementaryType("uint256"))
+    ir_get_length = Assignment(length_val, length, ElementaryType("uint256"))
+    ir_get_length.set_expression(ir.expression)
+    ir_get_length.set_node(ir.node)
+    ret.append(ir_get_length)
+
+    new_length_val = TemporaryVariable(node)
+    ir_add_1 = Binary(
+        new_length_val, length_val, Constant("1", ElementaryType("uint256")), BinaryType.ADDITION
+    )
+    ir_add_1.set_expression(ir.expression)
+    ir_add_1.set_node(ir.node)
+    ret.append(ir_add_1)
+
+    ir_assign_length = Assignment(length, new_length_val, ElementaryType("uint256"))
+    ir_assign_length.set_expression(ir.expression)
+    ir_assign_length.set_node(ir.node)
+    ret.append(ir_assign_length)
+
+    return length_val
+
+
+def convert_to_push_set_val(ir, node, length_val, ret):
+    arr = ir.destination
+
+    new_type = ir.destination.type.type
+
+    element_to_add = ReferenceVariable(node)
+    element_to_add.set_type(new_type)
+    ir_assign_element_to_add = Index(element_to_add, arr, length_val, ElementaryType("uint256"))
+    ir_assign_element_to_add.set_expression(ir.expression)
+    ir_assign_element_to_add.set_node(ir.node)
+    ret.append(ir_assign_element_to_add)
+
+    if len(ir.arguments) > 0:
+        assign_value = ir.arguments[0]
+        if isinstance(assign_value, list):
+            assign_value = TemporaryVariable(node)
+            assign_value.set_type(element_to_add.type)
+            ir_assign_value = InitArray(ir.arguments[0], assign_value)
+            ir_assign_value.set_expression(ir.expression)
+            ir_assign_value.set_node(ir.node)
+            ret.append(ir_assign_value)
+
+        ir_assign_value = Assignment(element_to_add, assign_value, assign_value.type)
+        ir_assign_value.set_expression(ir.expression)
+        ir_assign_value.set_node(ir.node)
+        ret.append(ir_assign_value)
+    else:
+        new_element = ir.lvalue
+        new_element.set_type(new_type)
+        ir_assign_value = Assignment(new_element, element_to_add, new_type)
+        ir_assign_value.set_expression(ir.expression)
+        ir_assign_value.set_node(ir.node)
+        ret.append(ir_assign_value)
+
+
 def convert_to_push(ir, node):
     """
-    Convert a call to a PUSH operaiton
+    Convert a call to a series of operations to push a new value onto the array
 
-    The funciton assume to receive a correct IR
+    The function assume to receive a correct IR
     The checks must be done by the caller
 
     May necessitate to create an intermediate operation (InitArray)
-    Necessitate to return the lenght (see push documentation)
+    Necessitate to return the length (see push documentation)
     As a result, the function return may return a list
     """
 
-    # TODO remove Push Operator, and change this to existing operators
+    ret = []
 
-    lvalue = ir.lvalue
-    if isinstance(ir.arguments[0], list):
-        ret = []
+    length_val = convert_to_push_expand_arr(ir, node, ret)
+    convert_to_push_set_val(ir, node, length_val, ret)
 
-        val = TemporaryVariable(node)
-        operation = InitArray(ir.arguments[0], val)
-        operation.set_expression(ir.expression)
-        operation.set_node(ir.node)
-        ret.append(operation)
-
-        prev_ir = ir
-        ir = Push(ir.destination, val)
-        ir.set_expression(prev_ir.expression)
-        ir.set_node(prev_ir.node)
-
-        length = Literal(len(operation.init_values), "uint256")
-        t = operation.init_values[0].type
-        ir.lvalue.set_type(ArrayType(t, length))
-
-        ret.append(ir)
-
-        if lvalue:
-            length = Length(ir.array, lvalue)
-            length.set_expression(ir.expression)
-            length.lvalue.points_to = ir.lvalue
-            length.set_node(ir.node)
-            ret.append(length)
-
-        return ret
-
-    prev_ir = ir
-    ir = Push(ir.destination, ir.arguments[0])
-    ir.set_expression(prev_ir.expression)
-    ir.set_node(prev_ir.node)
-
-    if lvalue:
-        ret = []
-        ret.append(ir)
-
-        length = Length(ir.array, lvalue)
-        length.set_expression(ir.expression)
-        length.lvalue.points_to = ir.lvalue
-        length.set_node(ir.node)
-        ret.append(length)
-        return ret
-
-    return ir
+    return ret
 
 
 def convert_to_pop(ir, node):
@@ -1148,11 +1146,7 @@ def look_for_library(contract, ir, using_for, t):
         lib_contract = contract.slither.get_contract_from_name(str(destination))
         if lib_contract:
             lib_call = LibraryCall(
-                lib_contract,
-                ir.function_name,
-                ir.nbr_arguments,
-                ir.lvalue,
-                ir.type_call,
+                lib_contract, ir.function_name, ir.nbr_arguments, ir.lvalue, ir.type_call,
             )
             lib_call.set_expression(ir.expression)
             lib_call.set_node(ir.node)
@@ -1385,14 +1379,7 @@ def remove_temporary(result):
         ins
         for ins in result
         if not isinstance(
-            ins,
-            (
-                Argument,
-                TmpNewElementaryType,
-                TmpNewContract,
-                TmpNewArray,
-                TmpNewStructure,
-            ),
+            ins, (Argument, TmpNewElementaryType, TmpNewContract, TmpNewArray, TmpNewStructure,),
         )
     ]
 
@@ -1427,6 +1414,12 @@ def remove_unused(result):
                 if not ins.lvalue.name in to_keep and ins != last_elem:
                     to_remove.append(ins)
                     removed = True
+            # Remove type(X) if X is an elementary type
+            # This assume that type(X) is only used with min/max
+            # If Solidity introduces other operation, we might remove this removal
+            if isinstance(ins, SolidityCall) and ins.function == SolidityFunction("type()"):
+                if isinstance(ins.arguments[0], ElementaryType):
+                    to_remove.append(ins)
 
         result = [i for i in result if not i in to_remove]
     return result
