@@ -1,3 +1,4 @@
+from slither.core.declarations import Function
 from slither.slithir.operations.operation import Operation
 
 from slither.slithir.variables.tuple import TupleVariable
@@ -6,16 +7,20 @@ from slither.slithir.utils.utils import is_valid_rvalue
 
 class Return(Operation):
     """
-       Return
-       Only present as last operation in RETURN node
+    Return
+    Only present as last operation in RETURN node
     """
 
     def __init__(self, values):
-        # Note: Can return None 
+        # Note: Can return None
         # ex: return call()
         # where call() dont return
         if not isinstance(values, list):
-            assert is_valid_rvalue(values) or isinstance(values, TupleVariable) or values is None
+            assert (
+                is_valid_rvalue(values)
+                or isinstance(values, (TupleVariable, Function))
+                or values is None
+            )
             if values is None:
                 values = []
             else:
@@ -27,14 +32,14 @@ class Return(Operation):
             # was valid for returns(uint)
             values = [v for v in values if not v is None]
             self._valid_value(values)
-        super(Return, self).__init__()
+        super().__init__()
         self._values = values
 
     def _valid_value(self, value):
         if isinstance(value, list):
             assert all(self._valid_value(v) for v in value)
         else:
-            assert is_valid_rvalue(value) or isinstance(value, TupleVariable)
+            assert is_valid_rvalue(value) or isinstance(value, (TupleVariable, Function))
         return True
 
     @property
@@ -46,4 +51,4 @@ class Return(Operation):
         return self._unroll(self._values)
 
     def __str__(self):
-        return "RETURN {}".format(','.join(['{}'.format(x) for x in self.values]))
+        return "RETURN {}".format(",".join(["{}".format(x) for x in self.values]))
