@@ -4,11 +4,10 @@ from slither.core.declarations.solidity_variables import SolidityVariable
 
 
 class Transfer(Call):
-
     def __init__(self, destination, value):
         assert isinstance(destination, (Variable, SolidityVariable))
         self._destination = destination
-        super(Transfer, self).__init__()
+        super().__init__()
 
         self._call_value = value
 
@@ -28,5 +27,5 @@ class Transfer(Call):
         return self._destination
 
     def __str__(self):
-        value = 'value:{}'.format(self.call_value)
-        return 'Transfer dest:{} {}'.format(self.destination, value)
+        value = "value:{}".format(self.call_value)
+        return "Transfer dest:{} {}".format(self.destination, value)
