@@ -1,26 +1,30 @@
-from slither.core.declarations import Event, Contract, SolidityVariableComposed, SolidityFunction, Structure
+from slither.core.declarations import (
+    Event,
+    Contract,
+    SolidityVariableComposed,
+    SolidityFunction,
+    Structure,
+)
 from slither.core.variables.variable import Variable
 from slither.slithir.operations.lvalue import OperationWithLValue
 
 
-class TmpCall(OperationWithLValue):
-
+class TmpCall(OperationWithLValue):  # pylint: disable=too-many-instance-attributes
     def __init__(self, called, nbr_arguments, result, type_call):
-        assert isinstance(called, (Contract,
-                                   Variable,
-                                   SolidityVariableComposed,
-                                   SolidityFunction,
-                                   Structure,
-                                   Event))
-        super(TmpCall, self).__init__()
+        assert isinstance(
+            called,
+            (Contract, Variable, SolidityVariableComposed, SolidityFunction, Structure, Event,),
+        )
+        super().__init__()
         self._called = called
         self._nbr_arguments = nbr_arguments
         self._type_call = type_call
         self._lvalue = result
-        self._ori = None # 
+        self._ori = None  #
         self._callid = None
         self._gas = None
         self._value = None
+        self._salt = None
 
     @property
     def call_value(self):
@@ -38,6 +42,14 @@ class TmpCall(OperationWithLValue):
     def call_gas(self, gas):
         self._gas = gas
 
+    @property
+    def call_salt(self):
+        return self._salt
+
+    @call_salt.setter
+    def call_salt(self, salt):
+        self._salt = salt
+
     @property
     def call_id(self):
         return self._callid
@@ -74,5 +86,4 @@ class TmpCall(OperationWithLValue):
         self._ori = ori
 
     def __str__(self):
-        return str(self.lvalue) +' = TMPCALL{} '.format(self.nbr_arguments)+ str(self._called) 
-
+        return str(self.lvalue) + " = TMPCALL{} ".format(self.nbr_arguments) + str(self._called)
