@@ -63,14 +63,7 @@ ERC223 = [
     ERC("totalSupply", [], "uint256", True, True, []),
     ERC("balanceOf", ["address"], "uint256", True, True, []),
     ERC("transfer", ["address", "uint256"], "bool", False, True, [ERC223_transfer_event]),
-    ERC(
-        "transfer",
-        ["address", "uint256", "bytes"],
-        "bool",
-        False,
-        True,
-        [ERC223_transfer_event],
-    ),
+    ERC("transfer", ["address", "uint256", "bytes"], "bool", False, True, [ERC223_transfer_event],),
     ERC(
         "transfer",
         ["address", "uint256", "bytes", "string"],
@@ -85,7 +78,7 @@ ERC223_signatures = erc_to_signatures(ERC223)
 # Final
 # https://eips.ethereum.org/EIPS/eip-165
 
-ERC165_EVENTS = []
+ERC165_EVENTS: List = []
 
 ERC165 = [ERC("supportsInterface", ["bytes4"], "bool", True, True, [])]
 ERC165_signatures = erc_to_signatures(ERC165)
@@ -125,22 +118,10 @@ ERC721 = [
         [ERC721_transfer_event],
     ),
     ERC(
-        "transferFrom",
-        ["address", "address", "uint256"],
-        "",
-        False,
-        True,
-        [ERC721_transfer_event],
+        "transferFrom", ["address", "address", "uint256"], "", False, True, [ERC721_transfer_event],
     ),
     ERC("approve", ["address", "uint256"], "", False, True, [ERC721_approval_event]),
-    ERC(
-        "setApprovalForAll",
-        ["address", "bool"],
-        "",
-        False,
-        True,
-        [ERC721_approvalforall_event],
-    ),
+    ERC("setApprovalForAll", ["address", "bool"], "", False, True, [ERC721_approvalforall_event],),
     ERC("getApproved", ["uint256"], "address", True, True, []),
     ERC("isApprovedForAll", ["address", "address"], "bool", True, True, []),
 ] + ERC165
@@ -157,16 +138,9 @@ ERC721_signatures = erc_to_signatures(ERC721)
 
 # Final
 # https://eips.ethereum.org/EIPS/eip-1820
-ERC1820_EVENTS = []
+ERC1820_EVENTS: List = []
 ERC1820 = [
-    ERC(
-        "canImplementInterfaceForAddress",
-        ["bytes32", "address"],
-        "bytes32",
-        True,
-        True,
-        [],
-    )
+    ERC("canImplementInterfaceForAddress", ["bytes32", "address"], "bytes32", True, True, [],)
 ]
 ERC1820_signatures = erc_to_signatures(ERC1820)
 
@@ -207,14 +181,7 @@ ERC777 = [
     ERC("granularity", [], "uint256", True, True, []),
     ERC("defaultOperators", [], "address[]", True, True, []),
     ERC("isOperatorFor", ["address", "address"], "bool", True, True, []),
-    ERC(
-        "authorizeOperator",
-        ["address"],
-        "",
-        False,
-        True,
-        [ERC777_authorizedOperator_event],
-    ),
+    ERC("authorizeOperator", ["address"], "", False, True, [ERC777_authorizedOperator_event],),
     ERC("revokeOperator", ["address"], "", False, True, [ERC777_revokedoperator_event]),
     ERC("send", ["address", "uint256", "bytes"], "", False, True, [ERC777_sent_event]),
     ERC(
