@@ -19,20 +19,24 @@ from slither.core.expressions.tuple_expression import TupleExpression
 from slither.core.expressions.type_conversion import TypeConversion
 from slither.all_exceptions import SlitherException
 
+# pylint: disable=protected-access
 def f_expressions(e, x):
     e._expressions.append(x)
 
+
 def f_call(e, x):
     e._arguments.append(x)
 
+
 def f_expression(e, x):
     e._expression = x
 
+
 def f_called(e, x):
     e._called = x
 
-class SplitTernaryExpression(object):
 
+class SplitTernaryExpression:
     def __init__(self, expression):
 
         if isinstance(expression, ConditionalExpression):
@@ -52,29 +56,31 @@ class SplitTernaryExpression(object):
             f(false_expression, copy.copy(next_expr.else_expression))
             self.condition = copy.copy(next_expr.if_expression)
             return False
-        else:
-            f(true_expression, copy.copy(next_expr))
-            f(false_expression, copy.copy(next_expr))
-            return True
 
-    def copy_expression(self, expression, true_expression, false_expression):
+        f(true_expression, copy.copy(next_expr))
+        f(false_expression, copy.copy(next_expr))
+        return True
+
+    def copy_expression(
+        self, expression, true_expression, false_expression
+    ):  # pylint: disable=too-many-branches
         if self.condition:
             return
 
         if isinstance(expression, ConditionalExpression):
-             raise SlitherException('Nested ternary operator not handled')
+            raise SlitherException("Nested ternary operator not handled")
 
         if isinstance(expression, (Literal, Identifier, IndexAccess, NewArray, NewContract)):
-            return None
+            return
 
         # case of lib
         # (.. ? .. : ..).add
         if isinstance(expression, MemberAccess):
             next_expr = expression.expression
             if self.apply_copy(next_expr, true_expression, false_expression, f_expression):
-                self.copy_expression(next_expr,
-                                     true_expression.expression,
-                                     false_expression.expression)
+                self.copy_expression(
+                    next_expr, true_expression.expression, false_expression.expression
+                )
 
         elif isinstance(expression, (AssignmentOperation, BinaryOperation, TupleExpression)):
             true_expression._expressions = []
@@ -83,9 +89,11 @@ class SplitTernaryExpression(object):
             for next_expr in expression.expressions:
                 if self.apply_copy(next_expr, true_expression, false_expression, f_expressions):
                     # always on last arguments added
-                    self.copy_expression(next_expr,
-                                         true_expression.expressions[-1],
-                                         false_expression.expressions[-1])
+                    self.copy_expression(
+                        next_expr,
+                        true_expression.expressions[-1],
+                        false_expression.expressions[-1],
+                    )
 
         elif isinstance(expression, CallExpression):
             next_expr = expression.called
@@ -93,9 +101,7 @@ class SplitTernaryExpression(object):
             # case of lib
             # (.. ? .. : ..).add
             if self.apply_copy(next_expr, true_expression, false_expression, f_called):
-                self.copy_expression(next_expr,
-                                     true_expression.called,
-                                     false_expression.called)
+                self.copy_expression(next_expr, true_expression.called, false_expression.called)
 
             true_expression._arguments = []
             false_expression._arguments = []
@@ -103,24 +109,25 @@ class SplitTernaryExpression(object):
             for next_expr in expression.arguments:
                 if self.apply_copy(next_expr, true_expression, false_expression, f_call):
                     # always on last arguments added
-                    self.copy_expression(next_expr,
-                                         true_expression.arguments[-1],
-                                         false_expression.arguments[-1])
+                    self.copy_expression(
+                        next_expr, true_expression.arguments[-1], false_expression.arguments[-1],
+                    )
 
         elif isinstance(expression, TypeConversion):
             next_expr = expression.expression
             if self.apply_copy(next_expr, true_expression, false_expression, f_expression):
-                self.copy_expression(expression.expression,
-                                     true_expression.expression,
-                                     false_expression.expression)
+                self.copy_expression(
+                    expression.expression, true_expression.expression, false_expression.expression,
+                )
 
         elif isinstance(expression, UnaryOperation):
             next_expr = expression.expression
             if self.apply_copy(next_expr, true_expression, false_expression, f_expression):
-                self.copy_expression(expression.expression,
-                                     true_expression.expression,
-                                     false_expression.expression)
+                self.copy_expression(
+                    expression.expression, true_expression.expression, false_expression.expression,
+                )
 
         else:
-            raise SlitherException('Ternary operation not handled {}({})'.format(expression, type(expression)))
-
+            raise SlitherException(
+                "Ternary operation not handled {}({})".format(expression, type(expression))
+            )
