@@ -4,7 +4,6 @@ from prettytable import PrettyTable
 
 
 class MyPrettyTable:
-
     def __init__(self, field_names: List[str]):
         self._field_names = field_names
         self._rows: List = []
@@ -12,17 +11,14 @@ class MyPrettyTable:
     def add_row(self, row):
         self._rows.append(row)
 
-    def to_pretty_table(self):
+    def to_pretty_table(self) -> PrettyTable:
         table = PrettyTable(self._field_names)
         for row in self._rows:
             table.add_row(row)
         return table
 
     def to_json(self) -> Dict:
-        return {
-            'fields_names': self._field_names,
-            'rows': self._rows
-        }
+        return {"fields_names": self._field_names, "rows": self._rows}
 
     def __str__(self):
-        return str(self.to_pretty_table())
\ No newline at end of file
+        return str(self.to_pretty_table())
