@@ -1,10 +1,12 @@
 import logging
+from typing import Any
 
 from slither.core.expressions.assignment_operation import AssignmentOperation
 from slither.core.expressions.binary_operation import BinaryOperation
 from slither.core.expressions.call_expression import CallExpression
 from slither.core.expressions.conditional_expression import ConditionalExpression
 from slither.core.expressions.elementary_type_name_expression import ElementaryTypeNameExpression
+from slither.core.expressions.expression import Expression
 from slither.core.expressions.identifier import Identifier
 from slither.core.expressions.index_access import IndexAccess
 from slither.core.expressions.literal import Literal
@@ -19,24 +21,24 @@ from slither.exceptions import SlitherError
 
 logger = logging.getLogger("ExpressionVisitor")
 
-class ExpressionVisitor:
 
-    def __init__(self, expression):
+class ExpressionVisitor:
+    def __init__(self, expression: Expression):
         # Inherited class must declared their variables prior calling super().__init__
         self._expression = expression
-        self._result = None
+        self._result: Any = None
         self._visit_expression(self.expression)
 
     def result(self):
         return self._result
 
     @property
-    def expression(self):
+    def expression(self) -> Expression:
         return self._expression
 
     # visit an expression
     # call pre_visit, visit_expression_name, post_visit
-    def _visit_expression(self, expression):
+    def _visit_expression(self, expression: Expression):  # pylint: disable=too-many-branches
         self._pre_visit(expression)
 
         if isinstance(expression, AssignmentOperation):
@@ -88,7 +90,7 @@ class ExpressionVisitor:
             pass
 
         else:
-            raise SlitherError('Expression not handled: {}'.format(expression))
+            raise SlitherError("Expression not handled: {}".format(expression))
 
         self._post_visit(expression)
 
@@ -111,6 +113,8 @@ class ExpressionVisitor:
             self._visit_expression(expression.call_value)
         if expression.call_gas:
             self._visit_expression(expression.call_gas)
+        if expression.call_salt:
+            self._visit_expression(expression.call_salt)
 
     def _visit_conditional_expression(self, expression):
         self._visit_expression(expression.if_expression)
@@ -155,7 +159,7 @@ class ExpressionVisitor:
 
     # pre visit
 
-    def _pre_visit(self, expression):
+    def _pre_visit(self, expression):  # pylint: disable=too-many-branches
         if isinstance(expression, AssignmentOperation):
             self._pre_assignement_operation(expression)
 
@@ -205,7 +209,7 @@ class ExpressionVisitor:
             pass
 
         else:
-            raise SlitherError('Expression not handled: {}'.format(expression))
+            raise SlitherError("Expression not handled: {}".format(expression))
 
     # pre_expression_name
 
@@ -256,7 +260,7 @@ class ExpressionVisitor:
 
     # post visit
 
-    def _post_visit(self, expression):
+    def _post_visit(self, expression):  # pylint: disable=too-many-branches
         if isinstance(expression, AssignmentOperation):
             self._post_assignement_operation(expression)
 
@@ -306,7 +310,7 @@ class ExpressionVisitor:
             pass
 
         else:
-            raise SlitherError('Expression not handled: {}'.format(expression))
+            raise SlitherError("Expression not handled: {}".format(expression))
 
     # post_expression_name
 
@@ -354,5 +358,3 @@ class ExpressionVisitor:
 
     def _post_unary_operation(self, expression):
         pass
-
-
